==> 1.0.0.tar.gz: ios/Classes/UmengAnalyticsPushIos.m <==
#import "UmengAnalyticsPushIos.h"
#import <UMCommon/UMCommon.h>
#import <UMCommon/MobClick.h>
#import <UMPush/UMessage.h>
#import <UserNotifications/UserNotifications.h>
#import <UMCommonLog/UMCommonLogHeaders.h>

extern FlutterEventSink _eventSink;
@implementation UmengAnalyticsPushFlutterIos

// 初始化友盟
+ (void)iosInit:(NSDictionary *_Nullable)launchOptions appkey:(NSString *)appkey channel:(NSString *)channel logEnabled:(BOOL)logEnabled pushEnabled:(BOOL)pushEnabled ncDelegate: (FlutterAppDelegate *)ncDelegate {
    [UMConfigure setLogEnabled:logEnabled];
    [UMConfigure initWithAppkey:appkey channel:channel];
    NSLog(@"application init umeng ok");
    if (pushEnabled) {
        // Push组件基本功能配置
        UMessageRegisterEntity * entity = [[UMessageRegisterEntity alloc] init];
        //type是对推送的几个参数的选择，可以选择一个或者多个。默认是三个全部打开，即：声音，弹窗，角标
        entity.types = UMessageAuthorizationOptionBadge|UMessageAuthorizationOptionSound|UMessageAuthorizationOptionAlert;
        [UNUserNotificationCenter currentNotificationCenter].delegate=ncDelegate;
        [UMessage registerForRemoteNotificationsWithLaunchOptions:launchOptions Entity:entity completionHandler:^(BOOL granted, NSError * _Nullable error) {
            if (granted) {
                NSLog(@"================= PUSH授权成功 ====================");
            } else {
                NSLog(@"================= PUSH拒绝授权 ====================");
            }
        }];
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(notificationFuncion:) name:@"umeng_analytics_push" object:nil];
    }
}


// 处理友盟推送
+ (void)handleMessagePush:(NSDictionary *)userInfo {
    if (userInfo)
    {
        NSDictionary *dUsrInfo = userInfo;

        NSMutableDictionary *message = [[NSMutableDictionary alloc] init];
        NSMutableDictionary *extra = [[NSMutableDictionary alloc] init];
        NSMutableDictionary *body = [[NSMutableDictionary alloc] init];

        [message setObject: @"" forKey: @"display_type"];
        [message setObject: @"12345678" forKey: @"msg_id"];
        
        //设置extra
        [message setObject: extra forKey: @"extra"];
        for (id key in dUsrInfo) {
            NSString *keyStr = (NSString *)key;
            if ([keyStr isEqualToString: @"aps"]) {
                continue;
            }

            id value = [dUsrInfo objectForKey: key];
            [extra setObject: value forKey: key];
        }

        //设置body
        NSDictionary *aps = [dUsrInfo objectForKey: @"aps"];
        NSDictionary *alert = [aps objectForKey: @"alert"];
        
        [body setObject: [alert objectForKey: @"title"] forKey: @"title"];
        [body setObject: [alert objectForKey: @"body"] forKey: @"text"];
        [body setObject: [alert objectForKey: @"subtitle"] forKey: @"ticker"];
        
        [message setObject: body forKey: @"body"];

        //to json
        NSString *jsonString = nil;
        NSError *error;
        NSData *jsonData = [NSJSONSerialization dataWithJSONObject:message options:NSJSONWritingPrettyPrinted error:&error];
        if (!jsonData) {
            NSLog(@"Got an error: %@", error);
        } else {
            jsonString = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
        }

        _eventSink(jsonString);
    }
}

//消息推送的格式
// iOS10之前的格式
// {  
//    "aps":{  
//       "alert":"内容",
//       "badge":1,
//       "sound":"default",
//       "userinfo":{"username":"tom"}
//    }
//    "extra1": "",
//    "extra2": "",
// }
// iOS 10及之后(iOS7、iOS8、iOS9可通用此模板)
// {  
//    "aps":{  
//       "alert":{  
//          "title":"标题", // iOS7、8设置无效，iOS9一般设置为appName
//          "subtitle":"子标题", // 一般使用title就能满足需求
//          "body":"内容"
//       },
//       "badge":1, //角标数
//       "sound":"default", //声音
//       "userinfo":{ //通知内容信息
//            "playid":"123",
//            "username":"tom",
//            "sex":1
//       }
//    }
//    "extra1": "",
//    "extra2": "",
// }

@end

==> 1.0.2.tar.gz: ios/Classes/UmengAnalyticsPushIos.m <==
#import "UmengAnalyticsPushIos.h"
#import <UMCommon/UMCommon.h>
#import <UMCommon/MobClick.h>
#import <UMPush/UMessage.h>
#import <UserNotifications/UserNotifications.h>
#import <UMCommonLog/UMCommonLogHeaders.h>

extern FlutterEventSink _eventSink;
@implementation UmengAnalyticsPushFlutterIos

// 初始化友盟
+ (void)iosInit:(NSDictionary *_Nullable)launchOptions appkey:(NSString *)appkey channel:(NSString *)channel logEnabled:(BOOL)logEnabled pushEnabled:(BOOL)pushEnabled ncDelegate: (FlutterAppDelegate *)ncDelegate {
    [UMConfigure setLogEnabled:logEnabled];
    [UMConfigure initWithAppkey:appkey channel:channel];
    NSLog(@"application init umeng ok");
    if (pushEnabled) {
        // Push组件基本功能配置
        UMessageRegisterEntity * entity = [[UMessageRegisterEntity alloc] init];
        //type是对推送的几个参数的选择，可以选择一个或者多个。默认是三个全部打开，即：声音，弹窗，角标
        entity.types = UMessageAuthorizationOptionBadge|UMessageAuthorizationOptionSound|UMessageAuthorizationOptionAlert;
        [UNUserNotificationCenter currentNotificationCenter].delegate=ncDelegate;
        [UMessage registerForRemoteNotificationsWithLaunchOptions:launchOptions Entity:entity completionHandler:^(BOOL granted, NSError * _Nullable error) {
            if (granted) {
                NSLog(@"================= PUSH授权成功 ====================");
            } else {
                NSLog(@"================= PUSH拒绝授权 ====================");
            }
        }];
        [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(notificationFuncion:) name:@"flutter_umeng_analytics_push" object:nil];
    }
}


// 处理友盟推送
+ (void)handleMessagePush:(NSDictionary *)userInfo {
    if (userInfo)
    {
        NSDictionary *dUsrInfo = userInfo;

        NSMutableDictionary *message = [[NSMutableDictionary alloc] init];
        NSMutableDictionary *extra = [[NSMutableDictionary alloc] init];
        NSMutableDictionary *body = [[NSMutableDictionary alloc] init];

        [message setObject: @"" forKey: @"display_type"];
        [message setObject: @"12345678" forKey: @"msg_id"];
        
        //设置extra
        [message setObject: extra forKey: @"extra"];
        for (id key in dUsrInfo) {
            NSString *keyStr = (NSString *)key;
            if ([keyStr isEqualToString: @"aps"]) {
                continue;
            }

            id value = [dUsrInfo objectForKey: key];
            [extra setObject: value forKey: key];
        }

        //设置body
        NSDictionary *aps = [dUsrInfo objectForKey: @"aps"];
        NSDictionary *alert = [aps objectForKey: @"alert"];
        
        [body setObject: [alert objectForKey: @"title"] forKey: @"title"];
        [body setObject: [alert objectForKey: @"body"] forKey: @"text"];
        [body setObject: [alert objectForKey: @"subtitle"] forKey: @"ticker"];
        
        [message setObject: body forKey: @"body"];

        //to json
        NSString *jsonString = nil;
        NSError *error;
        NSData *jsonData = [NSJSONSerialization dataWithJSONObject:message options:NSJSONWritingPrettyPrinted error:&error];
        if (!jsonData) {
            NSLog(@"Got an error: %@", error);
        } else {
            jsonString = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
        }

        _eventSink(jsonString);
    }
}

//消息推送的格式
// iOS10之前的格式
// {  
//    "aps":{  
//       "alert":"内容",
//       "badge":1,
//       "sound":"default",
//       "userinfo":{"username":"tom"}
//    }
//    "extra1": "",
//    "extra2": "",
// }
// iOS 10及之后(iOS7、iOS8、iOS9可通用此模板)
// {  
//    "aps":{  
//       "alert":{  
//          "title":"标题", // iOS7、8设置无效，iOS9一般设置为appName
//          "subtitle":"子标题", // 一般使用title就能满足需求
//          "body":"内容"
//       },
//       "badge":1, //角标数
//       "sound":"default", //声音
//       "userinfo":{ //通知内容信息
//            "playid":"123",
//            "username":"tom",
//            "sex":1
//       }
//    }
//    "extra1": "",
//    "extra2": "",
// }

@end
